## Welcome to ProxyCheck.io's unofficial python wrapper!
This is a unofficial asynchronous & synchronous wrapper for ProxyCheck.io API.

### Install
- Pip: ``pip3 install proxycheck``
- Git: ``pip3 install git+https://github.com/WardPearce/proxycheck.git``


### Documentation
[Documentation](https://proxycheck.readthedocs.io/en/latest/)


### Thanks to
- [Encode for creating HTTPX](https://www.python-httpx.org/)